# The base classes

All iCalendar Component classes and iCalendar Property classes inherit from `ICalBaseClass`.
Then [ICalBaseClass](ical_library.base_classes.ICalBaseClass) is extended by both [Component](ical_library.base_classes.Component) and [Property](ical_library.base_classes.Property).

::: ical_library.base_classes.ICalBaseClass


::: ical_library.base_classes.Component


::: ical_library.help_modules.component_context.ComponentContext
